Panku: Easy Reddit post fetcher designed for humans.

Example Code
```py
from Panku.panku import Reddit
python_sub = Reddit('github',count=5)
python_sub.read()
```

output

```
Using Base URL: https://old.reddit.com/r/Github/.json?limit=5

Have or know of a project on Github looking for contributors? Feel free to drop them down to add to the wiki page!
by iSaithh → https://reddit.com/r/github/comments/c4kccq/have_or_know_of_a_project_on_github_looking_for/

Need help creating a Java repo
by llamagish → https://reddit.com/r/github/comments/clexx8/need_help_creating_a_java_repo/

Help required: New Stickney Japanese IME installation
by engitect → https://reddit.com/r/github/comments/clf0dv/help_required_new_stickney_japanese_ime/

Best way to use GitHub pages to host v1.myproject.org, v2.myproject.org, vN.myproject.org?
by breck → https://reddit.com/r/github/comments/cl5fc2/best_way_to_use_github_pages_to_host/

Github pages site still active…even though I deleted the repo weeks ago
by zevthewolf → https://reddit.com/r/github/comments/cl4rae/github_pages_site_still_activeeven_though_i/

Had open-sourced a small script I wrote and mostly forgot about it. But then this happened and made my day!!!
by SkullTech101 → https://reddit.com/r/github/comments/ckpjv2/had_opensourced_a_small_script_i_wrote_and_mostly/

```

Installation - Installs to python default environment.

`py setup.py install`

Run from command line
`py panku.py -c (count) -s (subreddit)`
